Learn R Programming

ctmcd (version 1.4.4)

plotM: Matrix Plot Function

Description

Function to visualize matrices

Usage

plotM(mat, mattext, col = c("grey", "red"), main, las = 1, xlab = "To", 
ylab = "From", xnames, ynames, cex = min(1, nrow(mat)/8), fig = 3, opacity_factor)

Value

no value, plot function

Arguments

mat

a matrix

mattext

optional: matrix of strings replacing the original matrix entries

col

two element vector of basis colors for positive and negative matrix entries

main

optional: plot title

las

orientation of x and y axis elements

xlab

x axis name

ylab

y axis name

xnames

description of x axis elements

ynames

description of y axis elements

cex

font size

fig

number of significant figures to be plotted

opacity_factor

two element vector for specification of opacity for positive and negative parameter entry highlighting (must be greater than zero)

Author

Marius Pfeuffer

See Also

plot.gm, plot.gmci

Examples

Run this code
gm0=matrix(1,8,8)
diag(gm0)=0
diag(gm0)=-rowSums(gm0)
gm0[8,]=0

plotM(gm0)

Run the code above in your browser using DataLab