powered by
Function to visualize matrices
plotM(mat, mattext, col = c("grey", "red"), main, las = 1, xlab = "To", ylab = "From", xnames, ynames, cex = min(1, nrow(mat)/8), fig = 3, opacity_factor)
no value, plot function
a matrix
optional: matrix of strings replacing the original matrix entries
two element vector of basis colors for positive and negative matrix entries
optional: plot title
orientation of x and y axis elements
x axis name
y axis name
description of x axis elements
description of y axis elements
font size
number of significant figures to be plotted
two element vector for specification of opacity for positive and negative parameter entry highlighting (must be greater than zero)
Marius Pfeuffer
plot.gm, plot.gmci
plot.gm
plot.gmci
gm0=matrix(1,8,8) diag(gm0)=0 diag(gm0)=-rowSums(gm0) gm0[8,]=0 plotM(gm0)
Run the code above in your browser using DataLab